[Xfce4-commits] [apps/xfdashboard] 01/03: Use garcon_menu_element_get_visible() in virtual function should_show() of GAppInfo overriden by XfdashboardDesktopAppInfo as Garcon will perform all checks needed to determine if menu item is visible and could be shown, e.g. correct environment, is not hidden, installed at all by checking TryExec keyword etc.

noreply at xfce.org noreply at xfce.org
Tue Jun 6 12:03:56 CEST 2017


This is an automated email from the git hooks/post-receive script.

n   o   m   a   d       p   u   s   h   e   d       a       c   o   m   m   i   t       t   o       b   r   a   n   c   h       m   a   s   t   e   r   
   in repository apps/xfdashboard.

commit 7d860e93628feff42485206ca40d6671a165128f
Author: Stephan Haller <nomad at froevel.de>
Date:   Tue Jun 6 11:56:38 2017 +0200

    Use garcon_menu_element_get_visible() in virtual function should_show() of GAppInfo overriden by XfdashboardDesktopAppInfo as Garcon will perform all checks needed to determine if menu item is visible and could be shown, e.g. correct environment, is not hidden, installed at all by checking TryExec keyword etc.
    
    Fixes issue GH #151
---
 libxfdashboard/desktop-app-info.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/libxfdashboard/desktop-app-info.c b/libxfdashboard/desktop-app-info.c
index 6af9aa6..332ac6a 100644
--- a/libxfdashboard/desktop-app-info.c
+++ b/libxfdashboard/desktop-app-info.c
@@ -1030,8 +1030,8 @@ static gboolean _xfdashboard_desktop_app_info_gappinfo_should_show(GAppInfo *inA
 	/* If desktop app info has no item return FALSE here */
 	if(!priv->item) return(FALSE);
 
-	/* Check if menu item should be shown in current environment */
-	return(garcon_menu_item_get_show_in_environment(priv->item));
+	/* Check if menu item is visible and therefore can be shown */
+	return(garcon_menu_element_get_visible(GARCON_MENU_ELEMENT(priv->item)));
 }
 
 /* Get command-line of GAppInfo with which the application will be started */

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list